@@ -1,44 +1,40 @@
-package MHonArc::UTF8::ISO8859_15;
+package MHonArc::UTF8::ISO8859_3;
 +{
 '',' ',
-'','¡',
-'','¢',
+'','Ħ',
+'','˘',
 '','£',
-'','€',
-'','¥',
-'','Š',
+'','¤',
+'','Ĥ',
 '','§',
-'','š',
-'','©',
-'','ª',
-'','«',
-'','¬',
+'','¨',
+'','İ',
+'','Ş',
+'','Ğ',
+'','Ĵ',
 '','­',
-'','®',
-'','¯',
+'','Ż',
 '','°',
-'','±',
+'','ħ',
 '','²',
 '','³',
-'','Ž',
+'','´',
 '','µ',
-'','¶',
+'','ĥ',
 '','·',
-'','ž',
-'','¹',
-'','º',
-'','»',
-'','Œ',
-'','œ',
-'','Ÿ',
-'','¿',
+'','¸',
+'','ı',
+'','ş',
+'','ğ',
+'','ĵ',
+'','½',
+'','ż',
 '','À',
 '','Á',
 '','Â',
-'','Ã',
 '','Ä',
-'','Å',
-'','Æ',
+'','Ċ',
+'','Ĉ',
 '','Ç',
 '','È',
 '','É',
@@ -48,29 +44,27 @@ package MHonArc::UTF8::ISO8859_15;
 '','Í',
 '','Î',
 '','Ï',
-'','Ð',
 '','Ñ',
 '','Ò',
 '','Ó',
 '','Ô',
-'','Õ',
+'','Ġ',
 '','Ö',
 '','×',
-'','Ø',
+'','Ĝ',
 '','Ù',
 '','Ú',
 '','Û',
 '','Ü',
-'','Ý',
-'','Þ',
+'','Ŭ',
+'','Ŝ',
 '','ß',
 '','à',
 '','á',
 '','â',
-'','ã',
 '','ä',
-'','å',
-'','æ',
+'','ċ',
+'','ĉ',
 '','ç',
 '','è',
 '','é',
@@ -80,20 +74,19 @@ package MHonArc::UTF8::ISO8859_15;
 '','í',
 '','î',
 '','ï',
-'','ð',
 '','ñ',
 '','ò',
 '','ó',
 '','ô',
-'','õ',
+'','ġ',
 '','ö',
 '','÷',
-'','ø',
+'','ĝ',
 '','ù',
 '','ú',
 '','û',
 '','ü',
-'','ý',
-'','þ',
-'','ÿ',
+'','ŭ',
+'','ŝ',
+'','˙',
 };
